(Tosachai Profile) เป็นการทดลองอัพโหลดแพคเกจไปยัง pypi.org
==========================================================

PyPi: https://pypi.org/project/tosachaiprofile/

สวัสดีคร้าบ แพคเกจนี้เป็นแพคเกจที่อธิบายโปรไฟล์ของนาย Tosachai
และสามารถนำไปใช้กับผู้อื่นได้

วิธีติดตั้ง
~~~~~~~~~~~

เปิด CMD / Terminal

.. code:: python

   pip install tosachaiprofile

วิธีใช้งานแพ็คเพจนี้
~~~~~~~~~~~~~~~~~~~~

-  เปิด IDLE ขึ้นมาแล้วพิมพ์…

.. code:: python

   my = Profile('Boat')
   my.company = ('Indeebrew')
   my.hobby = ('Gaming','Programing','Traveling')
   print(my.name)
   my.show_email()
   my.show_myart()
   my.show_hobby() 

พัฒนาโดย: ทศชัย อินดี FB: https://www.facebook.com/TcLaguna
